===============================
``psyclone.psyir.nodes.member``
===============================

.. automodule:: psyclone.psyir.nodes.member

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.member


Classes
=======

- :py:class:`Member`:
  Node representing a membership expression of a structure.


.. autoclass:: Member
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Member
      :parts: 1
